<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Net_Pocketbell
 *
 * ポケットベル表記の数字<>カナ変換
 *
 * Developed on PHP versions 4.4.9
 *
 * @category   Net
 * @package    Pocketbell
 * @author     松井 健太郎 <matsui@ke-tai.org>
 * @copyright  ke-tai.org
 * @license    
 * @version    SVN: $Id$
 * @link       http://ke-tai.org/
 * @see        
 * @since      
 * @deprecated 
 *
 * 修正履歴:
 * 2009/04/18 新規作成
 */

/**
 * Pocketbellクラス
 */
class Pocketbell
{
	/**
	 * 変換表定義配列
	 */
	var $def;
	
	
	/**
	 * コンストラクタ
	 *
	 * @param	string		$mode		NTT（NTT方式） or TM（テレメッセージ）
	 */
	function Pocketbell($mode = 'NTT')
	{
		mb_internal_encoding('UTF-8');
		
		if ($mode == 'TM') {
			$this->setDefinitionTm();
		} else {
			$this->setDefinitionNtt();
		}
	}
	
	
	/**
	 * 数字→カナ変換
	 *
	 * @param	string		$str		数字を格納した文字列
	 *
	 * @return	string					変換後の文字列
	 */
	function num2kana($str)
	{
		$ret = '';
		for ($i = 0; $i < strlen($str); $i = $i + 2) {
			$first = substr($str, $i, 1);
			$second = substr($str, $i + 1, 1);
			$ret .= $this->def[$first][$second];
		}
		
		return $ret;
	}
	
	
	/**
	 * カナ→数字変換
	 *
	 * @param	string		$str		カナを格納した文字列
	 *
	 * @return	string					変換後の数字文字列
	 */
	function kana2num($str)
	{
		$ret = '';
		for ($i = 0; $i < mb_strlen($str); $i++) {
			for ($first = 0; $first < 10; $first++) {
				for ($second = 0; $second < 10; $second++) {
					if ($this->def[$first][$second] == mb_substr($str, $i, 1)) {
						$ret .= $first . $second;
					}
				}
			}
		}
		
		return $ret;
	}
	
	
	/**
	 * 定義配列セット（NTT）
	 */
	function setDefinitionNtt()
	{
		$this->def = array(
			'1' => array(
				'1' => 'ア', 
				'2' => 'イ', 
				'3' => 'ウ', 
				'4' => 'エ', 
				'5' => 'オ', 
				'6' => 'Ａ', 
				'7' => 'Ｂ', 
				'8' => 'Ｃ', 
				'9' => 'Ｄ', 
				'0' => '１'
			), 
			'2' => array(
				'1' => 'カ', 
				'2' => 'キ', 
				'3' => 'ク', 
				'4' => 'ケ', 
				'5' => 'コ', 
				'6' => 'Ｅ', 
				'7' => 'Ｆ', 
				'8' => 'Ｇ', 
				'9' => 'Ｈ', 
				'0' => '２'
			), 
			'3' => array(
				'1' => 'サ', 
				'2' => 'シ', 
				'3' => 'ス', 
				'4' => 'セ', 
				'5' => 'ソ', 
				'6' => 'Ｉ', 
				'7' => 'Ｊ', 
				'8' => 'Ｋ', 
				'9' => 'Ｌ', 
				'0' => '３'
			), 
			'4' => array(
				'1' => 'タ', 
				'2' => 'チ', 
				'3' => 'ツ', 
				'4' => 'テ', 
				'5' => 'ト', 
				'6' => 'Ｍ', 
				'7' => 'Ｎ', 
				'8' => 'Ｏ', 
				'9' => 'Ｐ', 
				'0' => '４'
			), 
			'5' => array(
				'1' => 'ナ', 
				'2' => 'ニ', 
				'3' => 'ヌ', 
				'4' => 'ネ', 
				'5' => 'ノ', 
				'6' => 'Ｑ', 
				'7' => 'Ｒ', 
				'8' => 'Ｓ', 
				'9' => 'Ｔ', 
				'0' => '５'
			), 
			'6' => array(
				'1' => 'ハ', 
				'2' => 'ヒ', 
				'3' => 'フ', 
				'4' => 'ヘ', 
				'5' => 'ホ', 
				'6' => 'Ｕ', 
				'7' => 'Ｖ', 
				'8' => 'Ｗ', 
				'9' => 'Ｘ', 
				'0' => '６'
			), 
			'7' => array(
				'1' => 'マ', 
				'2' => 'ミ', 
				'3' => 'ム', 
				'4' => 'メ', 
				'5' => 'モ', 
				'6' => 'Ｙ', 
				'7' => 'Ｚ', 
				'8' => '？', 
				'9' => '！', 
				'0' => '７'
			), 
			'8' => array(
				'1' => 'ヤ', 
				'2' => '（', 
				'3' => 'ユ', 
				'4' => '）', 
				'5' => 'ヨ', 
				'6' => '＃', 
				'7' => '＊', 
				'8' => '[ハート]', 
				'9' => '￥', 
				'0' => '８'
			), 
			'9' => array(
				'1' => 'ラ', 
				'2' => 'リ', 
				'3' => 'ル', 
				'4' => 'レ', 
				'5' => 'ロ', 
				'6' => '↑', 
				'7' => '↓', 
				'8' => '[時計]', 
				'9' => '[電話]', 
				'0' => '９'
			), 
			'0' => array(
				'1' => 'ワ', 
				'2' => 'ヲ', 
				'3' => 'ン', 
				'4' => '゛', 
				'5' => '゜', 
				'6' => '／', 
				'7' => '‐', 
				'8' => '＆', 
				'9' => '　', 
				'0' => '０'
			)
		);
	}
	
	
	/**
	 * 定義配列セット（テレメッセージ）
	 */
	function setDefinitionTm()
	{
		$this->def = array(
			'1' => array(
				'1' => 'ア', 
				'2' => 'イ', 
				'3' => 'ウ', 
				'4' => 'エ', 
				'5' => 'オ', 
				'6' => 'Ａ', 
				'7' => 'Ｂ', 
				'8' => 'Ｃ', 
				'9' => 'Ｄ', 
				'0' => 'Ｅ'
			), 
			'2' => array(
				'1' => 'カ', 
				'2' => 'キ', 
				'3' => 'ク', 
				'4' => 'ケ', 
				'5' => 'コ', 
				'6' => 'Ｆ', 
				'7' => 'Ｇ', 
				'8' => 'Ｈ', 
				'9' => 'Ｉ', 
				'0' => 'Ｊ'
			), 
			'3' => array(
				'1' => 'サ', 
				'2' => 'シ', 
				'3' => 'ス', 
				'4' => 'セ', 
				'5' => 'ソ', 
				'6' => 'Ｋ', 
				'7' => 'Ｌ', 
				'8' => 'Ｍ', 
				'9' => 'Ｎ', 
				'0' => 'Ｏ'
			), 
			'4' => array(
				'1' => 'タ', 
				'2' => 'チ', 
				'3' => 'ツ', 
				'4' => 'テ', 
				'5' => 'ト', 
				'6' => 'Ｐ', 
				'7' => 'Ｑ', 
				'8' => 'Ｒ', 
				'9' => 'Ｓ', 
				'0' => 'Ｔ'
			), 
			'5' => array(
				'1' => 'ナ', 
				'2' => 'ニ', 
				'3' => 'ヌ', 
				'4' => 'ネ', 
				'5' => 'ノ', 
				'6' => 'Ｕ', 
				'7' => 'Ｖ', 
				'8' => 'Ｗ', 
				'9' => 'Ｘ', 
				'0' => 'Ｙ'
			), 
			'6' => array(
				'1' => 'ハ', 
				'2' => 'ヒ', 
				'3' => 'フ', 
				'4' => 'ヘ', 
				'5' => 'ホ', 
				'6' => 'Ｚ', 
				'7' => '？', 
				'8' => '！', 
				'9' => '‐', 
				'0' => '／'
			), 
			'7' => array(
				'1' => 'マ', 
				'2' => 'ミ', 
				'3' => 'ム', 
				'4' => 'メ', 
				'5' => 'モ', 
				'6' => '￥', 
				'7' => '＆', 
				'8' => '[時計]', 
				'9' => '[電話]', 
				'0' => '[カップ]'
			), 
			'8' => array(
				'1' => 'ヤ', 
				'2' => '（', 
				'3' => 'ユ', 
				'4' => '）', 
				'5' => 'ヨ', 
				'6' => '＊', 
				'7' => '＃', 
				'8' => '　', 
				'9' => '　', 
				'0' => '　'
			), 
			'9' => array(
				'1' => 'ラ', 
				'2' => 'リ', 
				'3' => 'ル', 
				'4' => 'レ', 
				'5' => 'ロ', 
				'6' => '１', 
				'7' => '２', 
				'8' => '３', 
				'9' => '４', 
				'0' => '５'
			), 
			'0' => array(
				'1' => 'ワ', 
				'2' => 'ヲ', 
				'3' => 'ン', 
				'4' => '゛', 
				'5' => '゜', 
				'6' => '６', 
				'7' => '７', 
				'8' => '８', 
				'9' => '９', 
				'0' => '０'
			)
		);
	}
}

?>